@@ -3,6 +3,9 @@ from textspan.textspan import (
     align_spans_by_mapping,
     align_spans,
     remove_span_overlaps,
+    remove_span_overlaps_idx,
+    lift_spans_index,
+    lift_span_index,
 )
 
 __all__ = [
@@ -10,4 +13,7 @@ __all__ = [
     "align_spans_by_mapping",
     "align_spans",
     "remove_span_overlaps",
+    "remove_span_overlaps_idx",
+    "lift_span_index",
+    "lift_spans_index",
 ]
